@@ -1,7 +1,7 @@
 package Mail::DKIM::ARC::Signer;
 use strict;
 use warnings;
-our $VERSION = '1.20200513.1'; # VERSION
+our $VERSION = '1.20200708'; # VERSION
 # ABSTRACT: generates a DKIM signature for a message
 
 # Copyright 2017 FastMail Pty Ltd.  All Rights Reserved.
@@ -111,11 +111,16 @@ sub finish_header {
         $header =~ s/[\r\n]+$//;
         if ( $header =~ m/^Authentication-Results:/ ) {
             my ( $arval ) = $header =~ m/^Authentication-Results:[^;]*;\s*(.*)/is;
-            my $parsed = eval{ Mail::AuthenticationResults::Parser->new->parse( $header ) };
-            if ( my $error = $@ ) {
-              warn "Authentication-Results Header parse error: $error\n$header";
-              next HEADER;
-            }
+            my $parsed;
+	    eval {
+		$parsed= Mail::AuthenticationResults::Parser->new
+		    ->parse( $header );
+		1
+	    } || do {
+		my $error = $@;
+		warn "Authentication-Results Header parse error: $error\n$header";
+		next HEADER;
+            };
             my $ardom = $parsed->value->value;
 
             next
@@ -583,7 +588,7 @@ Mail::DKIM::ARC::Signer - generates a DKIM signature for a message
 
 =head1 VERSION
 
-version 1.20200513.1
+version 1.20200708
 
 =head1 SYNOPSIS
 
