@@ -1,7 +1,7 @@
 package Mail::DKIM::ARC::Verifier;
 use strict;
 use warnings;
-our $VERSION = '1.20200513.1'; # VERSION
+our $VERSION = '1.20200708'; # VERSION
 # ABSTRACT: verifies an ARC-Sealed message
 
 # Copyright 2017 FastMail Pty Ltd.  All Rights Reserved.
@@ -58,8 +58,8 @@ sub handle_header {
             local $SIG{__DIE__};
             my $signature = Mail::DKIM::ARC::MessageSignature->parse($line);
             $self->add_signature($signature);
-        };
-        if ($@) {
+	    1
+        } || do {
 
             # the only reason an error should be thrown is if the
             # signature really is unparse-able
@@ -68,7 +68,7 @@ sub handle_header {
 
             chomp( my $E = $@ );
             $self->{signature_reject_reason} = $E;
-        }
+        };
     }
 
     if ( lc($field_name) eq 'arc-seal' ) {
@@ -76,8 +76,8 @@ sub handle_header {
             local $SIG{__DIE__};
             my $signature = Mail::DKIM::ARC::Seal->parse($line);
             $self->add_signature($signature);
-        };
-        if ($@) {
+	    1
+        } || do {
 
             # the only reason an error should be thrown is if the
             # signature really is unparse-able
@@ -86,7 +86,7 @@ sub handle_header {
 
             chomp( my $E = $@ );
             $self->{signature_reject_reason} = $E;
-        }
+        };
     }
 
 }
@@ -317,12 +317,12 @@ sub check_public_key {
         #                $signature->instance, $empty_g_means_wildcard);
 
         die $@ if $@;
-    };
-    if ($@) {
+	1
+    } || do {
         my $E = $@;
         chomp $E;
         $self->{signature_reject_reason} = "public key: $E";
-    }
+    };
     return $result;
 }
 
@@ -417,13 +417,13 @@ sub _check_and_verify_signature {
     eval {
         local $SIG{__DIE__};
         $pkey = $signature->get_public_key;
-    };
-    if ($@) {
+	1
+    } || do  {
         my $E = $@;
         chomp $E;
         $self->{signature_reject_reason} = "public key: $E";
         return ( 'invalid', $self->{signature_reject_reason} );
-    }
+    };
 
     unless ( $self->check_public_key( $signature, $pkey ) ) {
         return ( 'invalid', $self->{signature_reject_reason} );
@@ -444,8 +444,8 @@ sub _check_and_verify_signature {
         local $SIG{__DIE__};
         $result = $algorithm->verify() ? 'pass' : 'fail';
         $details = $algorithm->{verification_details} || $@;
-    };
-    if ($@) {
+	1
+    } || do {
 
         # see also add_signature
         chomp( my $E = $@ );
@@ -457,7 +457,7 @@ sub _check_and_verify_signature {
         }
         $result  = 'fail';
         $details = $E;
-    }
+    };
     return ( $result, $details );
 }
 
@@ -621,7 +621,7 @@ Mail::DKIM::ARC::Verifier - verifies an ARC-Sealed message
 
 =head1 VERSION
 
-version 1.20200513.1
+version 1.20200708
 
 =head1 SYNOPSIS
 
